<?php

namespace Drupal\noindex\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SettingsForm.
 *
 * @package Drupal\noindex\Form
 */
class NoindexSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'noindex_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('noindex.settings')
      ->set('route_patterns', $form_state->getValue('route_patterns'))
      ->set('uri_patterns', $form_state->getValue('uri_patterns'))
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['noindex.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('noindex.settings');

    $form['description'] = [
      '#type' => 'markup',
      '#markup' => $this->t('<p>Noindex is configured by using path patterns or URI patterns, optionally utilizing regular expressions to match pages.</p>'),
    ];

    $form['route_patterns'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Route patterns'),
      '#description' => $this->t('A list of internal Drupal routes or regular expression patterns to match, one per line. Use # as the regex delimiter.'),
      '#default_value' => $config->get('route_patterns'),
    ];

    $form['uri_patterns'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Request URI patterns'),
      '#description' => $this->t('A list of external request URI paths or regular expression patterns to match. Use # as the regex delimiter.'),
      '#default_value' => $config->get('uri_patterns'),
    ];

    return parent::buildForm($form, $form_state);
  }

}
